.. engage-django-sdk documentation master file, created by
   sphinx-quickstart on Wed Apr 27 12:28:12 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Engage-Django SDK Reference Guide
=================================

For release |release|


This is the Engage SDK for Django applications.

The SDK provides a command line utility to determine in advance whether your
Django application can be deployed on Engage and to package it up for
Engage. This documentation is for reference. If you just want to get up and
running quickly, take a look at the Quickstart guide (in the SDK as 
quickstart_guide.rst or on the genForma website at
http:/beta.genforma.com/doc-django-quickstart.html).

Currently, only deploying to genForma's hosting service is
supported. Deployment to your own servers running Engage locally will
be supported in an upcoming release.

This documentation and the Engage SDK is Copyright 2011 by 
`genForma Corporation <http://genforma.com/>`_ . The Engage SDK is
made available under an Apache 2.0 license.

Contents:

.. toctree::
   :maxdepth: 2

   overview
   requirements
   deployment
   upgrading

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`search`
